abacusai.constants_autocomplete_response — AbacusAI documentation

# abacusai.constants_autocomplete_response

## Classes

`ConstantsAutocompleteResponse` | A dictionary of constants to be used in the autocomplete.

## Module Contents

class abacusai.constants_autocomplete_response.ConstantsAutocompleteResponse(client, maxPendingRequests=None, acceptanceDelay=None, debounceDelay=None, recordUserAction=None, validateSuggestion=None, validationLinesThreshold=None, maxTrackedRecentChanges=None, diffThreshold=None, derivativeThreshold=None, defaultSurroundingLines=None, maxTrackedVisitChanges=None, selectionCooldownMs=None, viewingCooldownMs=None, maxLines=None, editCooldownMs=None, scrollDebounceMs=None, lspDeadline=None, diagnosticsThreshold=None, diagnosticEachThreshold=None, numVsCodeSuggestions=None, minReindexingInterval=None, minRefreshSummaryInterval=None, summaryBatchSize=None, jobReorderInterval=None, stopRapidChanges=None, delaySummaryBatches=None, maxSymbolsFuzzyMatch=None, fuzzySymbolMatchThreshold=None, symbolsCacheUpdateInterval=None, symbolsStorageUpdateInterval=None, embeddingConstants=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A dictionary of constants to be used in the autocomplete.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - maxPendingRequests (int) – The maximum number of pending requests.

    - acceptanceDelay (int) – The acceptance delay.

    - debounceDelay (int) – The debounce delay.

    - recordUserAction (bool) – Whether to record user action.

    - validateSuggestion (bool) – Whether to validate the suggestion.

    - validationLinesThreshold (int) – The number of lines to validate the suggestion.

    - maxTrackedRecentChanges (int) – The maximum number of recent file changes to track.

    - diffThreshold (int) – The diff operations threshold.

    - derivativeThreshold (int) – The derivative threshold for deletions

    - defaultSurroundingLines (int) – The default number of surrounding lines to include in the recently visited context.

    - maxTrackedVisitChanges (int) – The maximum number of recently visited ranges to track.

    - selectionCooldownMs (int) – The cooldown time in milliseconds for selection changes.

    - viewingCooldownMs (int) – The cooldown time in milliseconds for viewing changes.

    - maxLines (int) – The maximum number of lines to include in recently visited context.

    - editCooldownMs (int) – The cooldown time in milliseconds after last edit.

    - scrollDebounceMs (int) – The debounce time in milliseconds for scroll events.

    - lspDeadline (int) – The deadline in milliseconds for LSP context.

    - diagnosticsThreshold (int) – The max number of diagnostics to show.

    - diagnosticEachThreshold (int) – The max number of characters to show for each diagnostic type.

    - numVsCodeSuggestions (int) – The number of VS Code suggestions to show.

    - minReindexingInterval (int) – The minimum interval between reindexes in ms.

    - minRefreshSummaryInterval (int) – The minimum interval between refresh summary in ms.

    - summaryBatchSize (int) – The batch size for code summary in autocomplete.

    - jobReorderInterval (int) – The interval in ms to reorder jobs in the job queue for summary.

    - stopRapidChanges (bool) – Whether to stop rapid changes in autocomplete.

    - delaySummaryBatches (int) – The delay in ms between summary batches.

    - maxSymbolsFuzzyMatch (int) – The max number of symbols to fuzzy match.

    - fuzzySymbolMatchThreshold (int) – The threshold for fuzzy symbol match.

    - symbolsCacheUpdateInterval (int) – The interval in ms to update the symbols cache.

    - symbolsStorageUpdateInterval (int) – The interval in ms to update the symbols storage.

    - embeddingConstants (codellmembeddingconstants) – Embedding constants

  max_pending_requests = None
  acceptance_delay = None
  debounce_delay = None
  record_user_action = None
  validate_suggestion = None
  validation_lines_threshold = None
  max_tracked_recent_changes = None
  diff_threshold = None
  derivative_threshold = None
  default_surrounding_lines = None
  max_tracked_visit_changes = None
  selection_cooldown_ms = None
  viewing_cooldown_ms = None
  max_lines = None
  edit_cooldown_ms = None
  scroll_debounce_ms = None
  lsp_deadline = None
  diagnostics_threshold = None
  diagnostic_each_threshold = None
  num_vs_code_suggestions = None
  min_reindexing_interval = None
  min_refresh_summary_interval = None
  summary_batch_size = None
  job_reorder_interval = None
  stop_rapid_changes = None
  delay_summary_batches = None
  max_symbols_fuzzy_match = None
  fuzzy_symbol_match_threshold = None
  symbols_cache_update_interval = None
  symbols_storage_update_interval = None
  embedding_constants = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict